@@ -30,6 +30,48 @@ info = {
 tmpl_info = Template(tmpl_info)
 
 
+def add_classification_labels(dataset, label_field, labels_path):
+    # https://voxel51.com/docs/fiftyone/user_guide/export_datasets.html#fiftyoneimageclassificationdataset-export
+    assert Path(labels_path).suffix == ".json"
+
+    with open(labels_path, "r") as f:
+        data = json.load(f)
+
+    assert "classes" in data and "labels" in data
+
+    db = {}
+    label_type = None
+    for k, v in data["labels"].items():
+        if isinstance(v, list):
+            if label_type is None:
+                label_type = "classifications"
+            assert label_type == "classifications"
+            classifications = [fol.Classification(**vi) for vi in v]
+            db[k] = fol.Classifications(classifications=classifications)
+        else:
+            if label_type is None:
+                label_type = "classification"
+            assert label_type == "classification"
+            db[k] = fol.Classification(**v)
+
+    filepaths, ids = dataset.values(["filepath", "id"])
+    id_map = {Path(k).stem: v for k, v in zip(filepaths, ids)}
+
+    stems_adds = set(db.keys())
+    stems_base = set(id_map.keys())
+
+    bad_stems = stems_adds - stems_base
+    if bad_stems:
+        print(f"Ignoring {len(bad_stems)} nonexistent images (eg {list(bad_stems)[:6]})")
+
+    stems = sorted(stems_adds & stems_base)
+    matched_ids = [id_map[stem] for stem in stems]
+    view = dataset.select(matched_ids, ordered=True)
+
+    labels = [db[stem] for stem in stems]
+    view.set_values(label_field, labels)
+
+
 def add_coco_labels(dataset, label_field, labels_path):
     # https://voxel51.com/docs/fiftyone/api/fiftyone.utils.coco.html#fiftyone.utils.coco.add_coco_labels
     assert Path(labels_path).suffix == ".json"
@@ -173,18 +215,19 @@ def add_dataset(dataset, skip_existing=True, insert_new=True, fields=None, expan
     raise NotImplementedError
 
 
-def create_dataset(dataset_name, dataset_type=None, classes=[], mask_targets={}):
+def create_dataset(dataset_name, dataset_type, classes=[], mask_targets={}):
     """Create an empty :class:`fiftyone.core.dataset.Dataset` with the name.
 
     Args:
-        dataset_name (str): a name for the dataset.
-        dataset_type (str, optional): supported values are ``("detection", "segmentation")``
+        dataset_name (str): a name for the dataset
+        dataset_type (str): supported values are ``("detection", "segmentation", "unknown")``
         classes (list, optional): defaults to []
         mask_targets (dict, optional): defaults to {}
 
     Returns:
         a :class:`fiftyone.core.dataset.Dataset`
     """
+    assert dataset_type in {"detection", "segmentation", "unknown"}
     dataset = fo.Dataset()
 
     dataset.name = dataset_name
@@ -192,7 +235,7 @@ def create_dataset(dataset_name, dataset_type=None, classes=[], mask_targets={})
 
     info = {
         "dataset_name": dataset_name,
-        "dataset_type": dataset_type if dataset_type else "unknown",
+        "dataset_type": dataset_type,
         "version": "001",
         "classes": classes,
         "mask_targets": mask_targets,
@@ -208,28 +251,28 @@ def create_dataset(dataset_name, dataset_type=None, classes=[], mask_targets={})
     return dataset
 
 
-def load_images_dir(dataset_dir, dataset_name=None, dataset_type=None, classes=[], mask_targets={}):
+def load_images_dir(dataset_dir, dataset_name, dataset_type, classes=[], mask_targets={}):
     """Create a :class:`fiftyone.core.dataset.Dataset` from the given directory of images.
 
     Args:
-        dataset_dir (str): a directory of images.
-        dataset_name (str, optional): a name for the dataset. Defaults to None.
-        dataset_type (str, optional): supported values are ``("detection", "segmentation")``
+        dataset_dir (str): a directory of images
+        dataset_name (str): a name for the dataset
+        dataset_type (str): supported values are ``("detection", "segmentation", "unknown")``
         classes (list, optional): defaults to []
         mask_targets (dict, optional): defaults to {}
 
     Returns:
         a :class:`fiftyone.core.dataset.Dataset`
     """
+    assert dataset_type in {"detection", "segmentation", "unknown"}
     dataset = fo.Dataset.from_images_dir(dataset_dir)
 
-    if dataset_name:
-        dataset.name = dataset_name
-        dataset.persistent = True
+    dataset.name = dataset_name
+    dataset.persistent = True
 
     info = {
-        "dataset_name": dataset_name if dataset_name else "dataset-name",
-        "dataset_type": dataset_type if dataset_type else "unknown",
+        "dataset_name": dataset_name,
+        "dataset_type": dataset_type,
         "version": "001",
         "classes": classes,
         "mask_targets": mask_targets,
@@ -265,6 +308,15 @@ def delete_datasets(names=None, non_persistent=True):
         fo.delete_non_persistent_datasets(verbose=True)
 
 
+def load_dataset(name):
+    """Loads the FiftyOne dataset with the given name.
+
+    Args:
+        name (str): the name of the dataset
+    """
+    return fo.load_dataset(name)
+
+
 def load_detection_dataset(dataset_dir, info_py="info.py", data_path="data", labels_path="labels.json", field_name="ground_truth", splits=None):
     dataset_dir = Path(dataset_dir)
 
@@ -299,6 +351,71 @@ def load_segmentation_dataset(dataset_dir, info_py="info.py", data_path="data",
     return dataset
 
 
+def export_classification_labels(export_dir, dataset, label_field, splits=None):
+    shutil.rmtree(export_dir, ignore_errors=True)
+
+    _tags = set(dataset.distinct("tags"))
+
+    if splits is None:
+        splits = ["train", "val", "test"]
+    elif splits == "auto":
+        splits = sorted(_tags)
+
+    assert isinstance(splits, list)
+    splits = [s for s in splits if s in _tags]
+
+    if not splits:
+        splits = ["train"]
+        dataset.tag_samples(splits)
+
+    for split in splits:
+        print(f"\n[{split}]\n")
+        view = dataset.match_tags(split)
+        curr_dir = Path(export_dir) / split
+
+        view.export(
+            dataset_type=fo.types.FiftyOneImageClassificationDataset,
+            labels_path=str(curr_dir / "labels.json"),
+            label_field=label_field,
+            include_confidence=True,
+        )
+
+    return export_dir
+
+
+def export_classification_dataset(export_dir, dataset, label_field, splits=None, export_media=True):
+    shutil.rmtree(export_dir, ignore_errors=True)
+
+    _tags = set(dataset.distinct("tags"))
+
+    if splits is None:
+        splits = ["train", "val", "test"]
+    elif splits == "auto":
+        splits = sorted(_tags)
+
+    assert isinstance(splits, list)
+    splits = [s for s in splits if s in _tags]
+
+    if not splits:
+        splits = ["train"]
+        dataset.tag_samples(splits)
+
+    for split in splits:
+        print(f"\n[{split}]\n")
+        view = dataset.match_tags(split)
+        curr_dir = Path(export_dir) / split
+
+        view.export(
+            export_dir=str(curr_dir),
+            dataset_type=fo.types.FiftyOneImageClassificationDataset,
+            export_media=export_media,
+            label_field=label_field,
+            include_confidence=True,
+        )
+
+    return export_dir
+
+
 def export_detection_dataset(export_dir, dataset, label_field, splits=None):
     return export_dataset(export_dir, dataset, label_field=label_field, splits=splits)
 
@@ -308,7 +425,16 @@ def export_segmentation_dataset(export_dir, dataset, label_field, mask_types="st
 
 
 def export_dataset(export_dir, dataset, label_field=None, mask_label_field=None, mask_types="stuff", splits=None):
-    # mask_types: "stuff"(amorphous regions of pixels), "thing"(connected regions, each representing an instance)
+    """Exports the samples in the collection to disk.
+
+    Args:
+        export_dir: the directory to which to export the samples
+        dataset: a :class:`fiftyone.core.collections.SampleCollection`
+        label_field: controls the label field(s) to export
+        mask_label_field: controls the label field(s) to export
+        mask_types ("stuff"): "stuff"(amorphous regions of pixels), "thing"(connected regions, each representing an instance)
+        splits (None): a list of strings, respectively, specifying the splits to load. If "auto" will computes the distinct tags
+    """
     assert label_field is not None or mask_label_field is not None
     shutil.rmtree(export_dir, ignore_errors=True)
 
@@ -326,10 +452,14 @@ def export_dataset(export_dir, dataset, label_field=None, mask_label_field=None,
     else:
         dataset = dataset.clone()
 
+    _tags = set(dataset.distinct("tags"))
+
     if splits is None:
         splits = ["train", "val", "test"]
+    elif splits == "auto":
+        splits = sorted(_tags)
 
-    _tags = set(dataset.distinct("tags"))
+    assert isinstance(splits, list)
     splits = [s for s in splits if s in _tags]
 
     if not splits:
