@@ -1,4 +1,5 @@
 import fiftyone as fo
+import fiftyone.core.view as fov
 
 
 def annotate(dataset_or_view, label_field="ground_truth", label_type="instances",
@@ -6,7 +7,12 @@ def annotate(dataset_or_view, label_field="ground_truth", label_type="instances"
              task_size=2000, segment_size=1000, task_assignee="hejian", job_assignees=["weiqiaomu", "jiasiyu"]):
     # `label_type` (None) - a string. The possible values are: `classification`, `classifications`, `detections`, `instances`, `segmentation`, `scalar`.
     # `mask_targets` (None) - a dict mapping pixel values to semantic label strings. Only applicable when annotating semantic segmentations.
-    anno_key = f"{dataset_or_view.name}_{label_field}_{label_type}"
+    if isinstance(dataset_or_view, fov.DatasetView):
+        dataset_name = dataset_or_view.dataset_name
+    else:
+        dataset_name = dataset_or_view.name
+
+    anno_key = f"{dataset_name}_{label_field}_{label_type}"
 
     # The new attributes that we want to populate
     attributes = True
@@ -38,10 +44,10 @@ def annotate(dataset_or_view, label_field="ground_truth", label_type="instances"
         project_name=anno_key,
     )
 
-    return {"dataset_name": dataset_or_view.name, "anno_key": anno_key}
+    return {"dataset_name": dataset_name, "anno_key": anno_key}
 
 
-def load_annotations(dataset_name, anno_key, cleanup=False,
+def load_annotations(dataset_name, anno_key, cleanup=True,
                      url="http://119.23.212.113:6060", username="hejian", password="LFIcvat123"):
     dataset = fo.load_dataset(dataset_name)
 
