@@ -4,7 +4,7 @@ from pathlib import Path
 
 import cv2 as cv
 
-suffix_set = set(".avi,.mp4,.MOV".split(","))
+suffix_set = set(".avi,.mp4,.MOV,.mkv".split(","))
 
 
 def video_info(fpath):
